#[repr(C)]pub struct ResetToggleWithTimeoutRequest {
pub timeout: i64,
}Fields
timeout: i64Trait Implementations
Sourceimpl Clone for ResetToggleWithTimeoutRequest
impl Clone for ResetToggleWithTimeoutRequest
Sourcefn clone(&self) -> ResetToggleWithTimeoutRequest
fn clone(&self) -> ResetToggleWithTimeoutRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'a, ___E> Encode<ResetToggleWithTimeoutRequest, ___E> for &'a ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ResetToggleWithTimeoutRequest, ___E> for &'a ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ResetToggleWithTimeoutRequest, ___E> for ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ResetToggleWithTimeoutRequest, ___E> for ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ResetToggleWithTimeoutRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ResetToggleWithTimeoutRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, ResetToggleWithTimeoutRequest>, ___E> for &'a ResetToggleWithTimeoutRequestwhere
___E: Encoder + ?Sized,
&'a ResetToggleWithTimeoutRequest: Encode<ResetToggleWithTimeoutRequest, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, ResetToggleWithTimeoutRequest>, ___E> for &'a ResetToggleWithTimeoutRequestwhere
___E: Encoder + ?Sized,
&'a ResetToggleWithTimeoutRequest: Encode<ResetToggleWithTimeoutRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ResetToggleWithTimeoutRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ResetToggleWithTimeoutRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, ResetToggleWithTimeoutRequest>, ___E> for ResetToggleWithTimeoutRequestwhere
___E: Encoder + ?Sized,
ResetToggleWithTimeoutRequest: Encode<ResetToggleWithTimeoutRequest, ___E>,
impl<___E> EncodeOption<Box<'static, ResetToggleWithTimeoutRequest>, ___E> for ResetToggleWithTimeoutRequestwhere
___E: Encoder + ?Sized,
ResetToggleWithTimeoutRequest: Encode<ResetToggleWithTimeoutRequest, ___E>,
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, ResetToggleWithTimeoutRequest>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, ResetToggleWithTimeoutRequest>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
impl FromWire<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ResetToggleWithTimeoutRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ResetToggleWithTimeoutRequest, Self>
Sourcefn from_wire(wire: ResetToggleWithTimeoutRequest) -> Self
fn from_wire(wire: ResetToggleWithTimeoutRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
impl FromWireRef<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
Sourcefn from_wire_ref(wire: &ResetToggleWithTimeoutRequest) -> Self
fn from_wire_ref(wire: &ResetToggleWithTimeoutRequest) -> Self
Converts the given reference to this type.
Sourceimpl Hash for ResetToggleWithTimeoutRequest
impl Hash for ResetToggleWithTimeoutRequest
Sourceimpl Ord for ResetToggleWithTimeoutRequest
impl Ord for ResetToggleWithTimeoutRequest
Sourcefn cmp(&self, other: &ResetToggleWithTimeoutRequest) -> Ordering
fn cmp(&self, other: &ResetToggleWithTimeoutRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for ResetToggleWithTimeoutRequest
impl PartialEq for ResetToggleWithTimeoutRequest
Sourcefn eq(&self, other: &ResetToggleWithTimeoutRequest) -> bool
fn eq(&self, other: &ResetToggleWithTimeoutRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for ResetToggleWithTimeoutRequest
impl PartialOrd for ResetToggleWithTimeoutRequest
impl Copy for ResetToggleWithTimeoutRequest
impl Eq for ResetToggleWithTimeoutRequest
impl StructuralPartialEq for ResetToggleWithTimeoutRequest