#[repr(C)]pub struct ResetToggleWithTimeoutRequest {
pub timeout: Int64,
}Expand description
The wire type corresponding to ResetToggleWithTimeoutRequest.
Fields
timeout: Int64Trait Implementations
Sourceimpl Clone for ResetToggleWithTimeoutRequest
impl Clone for ResetToggleWithTimeoutRequest
Sourcefn clone(&self) -> ResetToggleWithTimeoutRequest
fn clone(&self) -> ResetToggleWithTimeoutRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for ResetToggleWithTimeoutRequest
impl Constrained for ResetToggleWithTimeoutRequest
Sourceimpl<___D> Decode<___D> for ResetToggleWithTimeoutRequestwhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for ResetToggleWithTimeoutRequestwhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<ResetToggleWithTimeoutRequest, ___E> for &'a ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<ResetToggleWithTimeoutRequest, ___E> for &'a ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<ResetToggleWithTimeoutRequest, ___E> for ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<ResetToggleWithTimeoutRequest, ___E> for ResetToggleWithTimeoutRequestwhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self, ResetToggleWithTimeoutRequest>
const COPY_OPTIMIZATION: CopyOptimization<Self, ResetToggleWithTimeoutRequest>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0> Encode<ResetToggleWithTimeoutRequest, ___E> for ResetToggleWithTimeoutRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
impl<___E, T0> Encode<ResetToggleWithTimeoutRequest, ___E> for ResetToggleWithTimeoutRequest<T0>where
___E: InternalHandleEncoder + ?Sized,
T0: Encode<Int64, ___E>,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<ResetToggleWithTimeoutRequest>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
impl FromWire<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
Sourceconst COPY_OPTIMIZATION: CopyOptimization<ResetToggleWithTimeoutRequest, Self>
const COPY_OPTIMIZATION: CopyOptimization<ResetToggleWithTimeoutRequest, Self>
Sourcefn from_wire(wire: ResetToggleWithTimeoutRequest) -> Self
fn from_wire(wire: ResetToggleWithTimeoutRequest) -> Self
Converts the given owned value to this type.
Sourceimpl FromWireRef<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
impl FromWireRef<ResetToggleWithTimeoutRequest> for ResetToggleWithTimeoutRequest
Sourcefn from_wire_ref(wire: &ResetToggleWithTimeoutRequest) -> Self
fn from_wire_ref(wire: &ResetToggleWithTimeoutRequest) -> Self
Converts the given reference to this type.
Sourceimpl IntoNatural for ResetToggleWithTimeoutRequest
impl IntoNatural for ResetToggleWithTimeoutRequest
Sourcetype Natural = ResetToggleWithTimeoutRequest
type Natural = ResetToggleWithTimeoutRequest
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for ResetToggleWithTimeoutRequest
impl Wire for ResetToggleWithTimeoutRequest
Sourcetype Narrowed<'de> = ResetToggleWithTimeoutRequest
type Narrowed<'de> = ResetToggleWithTimeoutRequest
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<Self>)
fn zero_padding(out_: &mut MaybeUninit<Self>)
Writes zeroes to the padding for this type, if any.